@@ -1,5 +1,8 @@
 #define _INCLUDE_XOPEN_SOURCE_EXTENDED
 
+#include <sys/unistd.h>
+#include <sys/resource.h>
+
 #ifdef _LARGEFILE64_SOURCE
 #define HAS_RLIMIT_64
 #endif
